@@ -156,7 +156,6 @@ def _check_coords_range(selected_range, coordinate, full_range):
         return sorted(full_range)
 
     if not isinstance(selected_range, (list, tuple)):
-
         if len(selected_range) != 2:
             raise ValueError(
                 f"The {coordinate} range must be None or a two-element tuple or list"
@@ -811,7 +810,7 @@ def import_knmi_hdf5(filename, qty="ACRR", accutime=5.0, pixelsize=1000.0, **kwa
     # the no data value. The precision of the data is two decimals (0.01 mm).
     if qty == "ACRR":
         precip = np.where(
-            precip_intermediate == 65535, np.NaN, precip_intermediate / 100.0
+            precip_intermediate == 65535, np.nan, precip_intermediate / 100.0
         )
 
     # In case reflectivities are imported, the no data value is 255. Values are
@@ -819,7 +818,7 @@ def import_knmi_hdf5(filename, qty="ACRR", accutime=5.0, pixelsize=1000.0, **kwa
     # as: dBZ = 0.5 * pixel_value - 32.0 (this used to be 31.5).
     if qty == "DBZH":
         precip = np.where(
-            precip_intermediate == 255, np.NaN, precip_intermediate * 0.5 - 32.0
+            precip_intermediate == 255, np.nan, precip_intermediate * 0.5 - 32.0
         )
 
     if precip is None:
@@ -943,7 +942,6 @@ def import_mch_gif(filename, product, unit, accutime, **kwargs):
     img = Image.open(filename)
 
     if product.lower() in ["azc", "rzc", "precip"]:
-
         # convert 8-bit GIF colortable to RGB values
         img_rgb = img.convert("RGB")
 
@@ -974,7 +972,6 @@ def import_mch_gif(filename, product, unit, accutime, **kwargs):
         precip[precip > 9999] = np.nan
 
     elif product.lower() in ["aqc", "cpc", "acquire ", "combiprecip"]:
-
         # convert digital numbers to physical values
         img = np.array(img).astype(int)
 
@@ -1369,15 +1366,18 @@ def import_odim_hdf5(filename, qty="RATE", **kwargs):
                                     mask = np.logical_and(~mask_u, ~mask_n)
                                     quality = np.empty(arr.shape)  # , dtype=float)
                                     quality[mask] = arr[mask] * gain + offset
-                                    quality[
-                                        ~mask
-                                    ] = np.nan  # a qui -----------------------------
+                                    quality[~mask] = (
+                                        np.nan
+                                    )  # a qui -----------------------------
 
     if precip is None:
         raise IOError("requested quantity %s not found" % qty)
 
     where = f["where"]
-    proj4str = where.attrs["projdef"].decode()
+    if isinstance(where.attrs["projdef"], str):
+        proj4str = where.attrs["projdef"]
+    else:
+        proj4str = where.attrs["projdef"].decode()
     pr = pyproj.Proj(proj4str)
 
     ll_lat = where.attrs["LL_lat"]
@@ -1546,7 +1546,6 @@ def import_saf_crri(filename, extent=None, **kwargs):
         metadata["y2"] = ycoord[idx_y].max() + metadata["ypixelsize"] / 2
 
     else:
-
         idx_x = None
         idx_y = None
 
