@@ -13,12 +13,13 @@ correlation between two images.
 """
 
 import numpy as np
-import scipy.ndimage.interpolation as ip
 import scipy.optimize as op
+from scipy.ndimage import map_coordinates
 
 
 def constant(R, **kwargs):
-    """Compute a constant advection field by finding a translation vector that
+    """
+    Compute a constant advection field by finding a translation vector that
     maximizes the correlation between two successive images.
 
     Parameters
@@ -39,7 +40,7 @@ def constant(R, **kwargs):
 
     def f(v):
         XYW = [Y + v[1], X + v[0]]
-        R_w = ip.map_coordinates(
+        R_w = map_coordinates(
             R[-2, :, :], XYW, mode="constant", cval=np.nan, order=0, prefilter=False
         )
 
