@@ -1,3 +1,4 @@
+# -- coding: utf-8 --
 """
 pysteps.verification.detcontscores
 ==================================
@@ -20,18 +21,16 @@ from scipy.stats import spearmanr
 
 
 def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
-    """Calculate simple and skill scores for deterministic continuous forecasts.
+    """
+    Calculate simple and skill scores for deterministic continuous forecasts.
 
     Parameters
     ----------
-
-    pred : array_like
+    pred: array_like
         Array of predictions. NaNs are ignored.
-
-    obs : array_like
+    obs: array_like
         Array of verifying observations. NaNs are ignored.
-
-    scores : {string, list of strings}, optional
+    scores: {string, list of strings}, optional
         The name(s) of the scores. The default, scores="", will compute all
         available scores.
         The available score names are:
@@ -70,7 +69,7 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
         |            | as in Germann et al. (2006)                            |
         +------------+--------------------------------------------------------+
 
-    axis : {int, tuple of int, None}, optional
+    axis: {int, tuple of int, None}, optional
         Axis or axes along which a score is integrated. The default, axis=None,
         will integrate all of the elements of the input arrays.\n
         If axis is -1 (or any negative integer),
@@ -78,26 +77,22 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
         and scores are computed on all of the elements in the input arrays.\n
         If axis is a tuple of ints, the integration is performed on all of the
         axes specified in the tuple.
-
-    conditioning : {None, "single", "double"}, optional
+    conditioning: {None, "single", "double"}, optional
         The type of conditioning used for the verification.
         The default, conditioning=None, includes all pairs. With
         conditioning="single", only pairs with either pred or obs > thr are
         included. With conditioning="double", only pairs with both pred and
         obs > thr are included.
-
-    thr : float
+    thr: float
         Optional threshold value for conditioning. Defaults to 0.
 
     Returns
     -------
-
-    result : dict
+    result: dict
         Dictionary containing the verification results.
 
     Notes
     -----
-
     Multiplicative scores can be computed by passing log-tranformed values.
     Note that "scatter" is the only score that will be computed in dB units of
     the multiplicative error, i.e.: 10*log10(pred/obs).
@@ -119,10 +114,8 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
     these cannot be computed using _init, _accum and _compute methods of this
     module.
 
-
     References
     ----------
-
     Germann, U. , Galli, G. , Boscacci, M. and Bolliger, M. (2006), Radar
     precipitation measurement in a mountainous region. Q.J.R. Meteorol. Soc.,
     132: 1669-1692. doi:10.1256/qj.05.190
@@ -133,7 +126,6 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
 
     See also
     --------
-
     pysteps.verification.detcatscores.det_cat_fct
     """
 
@@ -162,7 +154,6 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
     # online scores
     onresult = {}
     if onscores:
-
         err = det_cont_fct_init(axis=axis, conditioning=conditioning, thr=thr)
         det_cont_fct_accum(err, pred, obs)
         onresult = det_cont_fct_compute(err, onscores)
@@ -170,7 +161,6 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
     # offline scores
     offresult = {}
     if offscores:
-
         pred = np.asarray(pred.copy())
         obs = np.asarray(obs.copy())
 
@@ -216,12 +206,12 @@ def det_cont_fct(pred, obs, scores="", axis=None, conditioning=None, thr=0.0):
 
 
 def det_cont_fct_init(axis=None, conditioning=None, thr=0.0):
-    """Initialize a verification error object.
+    """
+    Initialize a verification error object.
 
     Parameters
     ----------
-
-    axis : {int, tuple of int, None}, optional
+    axis: {int, tuple of int, None}, optional
         Axis or axes along which a score is integrated. The default, axis=None,
         will integrate all of the elements of the input arrays.\n
         If axis is -1 (or any negative integer),
@@ -229,23 +219,19 @@ def det_cont_fct_init(axis=None, conditioning=None, thr=0.0):
         and scores are computed on all of the elements in the input arrays.\n
         If axis is a tuple of ints, the integration is performed on all of the
         axes specified in the tuple.
-
-    conditioning : {None, "single", "double"}, optional
+    conditioning: {None, "single", "double"}, optional
         The type of conditioning used for the verification.
         The default, conditioning=None, includes all pairs. With
         conditioning="single", only pairs with either pred or obs > thr are
         included. With conditioning="double", only pairs with both pred and
         obs > thr are included.
-
-    thr : float
+    thr: float
         Optional threshold value for conditioning. Defaults to 0.
 
     Returns
     -------
-
-    out : dict
+    out: dict
         The verification error object.
-
     """
 
     err = {}
@@ -281,20 +267,16 @@ def det_cont_fct_accum(err, pred, obs):
 
     Parameters
     ----------
-
-    err : dict
+    err: dict
         A verification error object initialized with
         :py:func:`pysteps.verification.detcontscores.det_cont_fct_init`.
-
-    pred : array_like
+    pred: array_like
         Array of predictions. NaNs are ignored.
-
-    obs : array_like
+    obs: array_like
         Array of verifying observations. NaNs are ignored.
 
     References
     ----------
-
     Chan, Tony F.; Golub, Gene H.; LeVeque, Randall J. (1979), "Updating
     Formulae and a Pairwise Algorithm for Computing Sample Variances.",
     Technical Report STAN-CS-79-773, Department of Computer Science,
@@ -372,8 +354,8 @@ def det_cont_fct_accum(err, pred, obs):
     mobs = np.nanmean(obs, axis=axis)
     mpred = np.nanmean(pred, axis=axis)
     me = np.nanmean(res, axis=axis)
-    mse = np.nanmean(res ** 2, axis=axis)
-    mss = np.nanmean(sum ** 2, axis=axis)
+    mse = np.nanmean(res**2, axis=axis)
+    mss = np.nanmean(sum**2, axis=axis)
     mae = np.nanmean(np.abs(res), axis=axis)
 
     # expand axes for broadcasting
@@ -409,18 +391,17 @@ def det_cont_fct_accum(err, pred, obs):
 
 
 def det_cont_fct_merge(err_1, err_2):
-    """Merge two verification error objects.
+    """
+    Merge two verification error objects.
 
     Parameters
     ----------
-
-    err_1 : dict
+    err_1: dict
       A verification error object initialized with
       :py:func:`pysteps.verification.detcontscores.det_cont_fct_init`
       and populated with
       :py:func:`pysteps.verification.detcontscores.det_cont_fct_accum`.
-
-    err_2 : dict
+    err_2: dict
       Another verification error object initialized with
       :py:func:`pysteps.verification.detcontscores.det_cont_fct_init`
       and populated with
@@ -428,8 +409,7 @@ def det_cont_fct_merge(err_1, err_2):
 
     Returns
     -------
-
-    out : dict
+    out: dict
       The merged verification error object.
     """
 
@@ -457,7 +437,7 @@ def det_cont_fct_merge(err_1, err_2):
 
     # update variances
     _parallel_var(
-        err["mobs"], err["n"], err["vobs"], err_2["mobs"], err_2["n"], err_2["vobs"],
+        err["mobs"], err["n"], err["vobs"], err_2["mobs"], err_2["n"], err_2["vobs"]
     )
     _parallel_var(
         err["mpred"],
@@ -495,19 +475,18 @@ def det_cont_fct_merge(err_1, err_2):
 
 
 def det_cont_fct_compute(err, scores=""):
-    """Compute simple and skill scores for deterministic continuous forecasts
+    """
+    Compute simple and skill scores for deterministic continuous forecasts
     from a verification error object.
 
     Parameters
     ----------
-
-    err : dict
+    err: dict
         A verification error object initialized with
         :py:func:`pysteps.verification.detcontscores.det_cont_fct_init` and
         populated with
         :py:func:`pysteps.verification.detcontscores.det_cont_fct_accum`.
-
-    scores : {string, list of strings}, optional
+    scores: {string, list of strings}, optional
         The name(s) of the scores. The default, scores="", will compute all
         available scores.
         The available score names are:
@@ -543,8 +522,7 @@ def det_cont_fct_compute(err, scores=""):
 
     Returns
     -------
-
-    result : dict
+    result: dict
         Dictionary containing the verification results.
     """
 
@@ -621,8 +599,7 @@ def det_cont_fct_compute(err, scores=""):
 
 
 def _parallel_mean(avg_a, count_a, avg_b, count_b):
-    """Update avg_a with avg_b.
-    """
+    """Update avg_a with avg_b."""
     idx = count_b > 0
     avg_a[idx] = (count_a[idx] * avg_a[idx] + count_b[idx] * avg_b[idx]) / (
         count_a[idx] + count_b[idx]
@@ -630,7 +607,8 @@ def _parallel_mean(avg_a, count_a, avg_b, count_b):
 
 
 def _parallel_var(avg_a, count_a, var_a, avg_b, count_b, var_b):
-    """Update var_a with var_b.
+    """
+    Update var_a with var_b.
     source: https://en.wikipedia.org/wiki/Algorithms_for_calculating_variance
     """
     idx = count_b > 0
@@ -646,8 +624,7 @@ def _parallel_var(avg_a, count_a, var_a, avg_b, count_b, var_b):
 
 
 def _parallel_cov(cov_a, avg_xa, avg_ya, count_a, cov_b, avg_xb, avg_yb, count_b):
-    """Update cov_a with cov_b.
-    """
+    """Update cov_a with cov_b."""
     idx = count_b > 0
     deltax = avg_xb - avg_xa
     deltay = avg_yb - avg_ya
@@ -671,7 +648,6 @@ def _uniquelist(mylist):
 
 
 def _scatter(pred, obs, axis=None):
-
     pred = pred.copy()
     obs = obs.copy()
 
@@ -687,7 +663,7 @@ def _scatter(pred, obs, axis=None):
     axis = get_iterable(axis)
 
     # reshape arrays as 2d matrices
-    # rows : samples; columns : variables
+    # rows: samples; columns: variables
     axis = tuple(range(pred.ndim)) if axis is None else axis
     axis = tuple(np.sort(axis))
     for ax in axis:
@@ -725,7 +701,6 @@ def _scatter(pred, obs, axis=None):
 
 
 def _spearmanr(pred, obs, axis=None):
-
     pred = pred.copy()
     obs = obs.copy()
 
@@ -741,7 +716,7 @@ def _spearmanr(pred, obs, axis=None):
     axis = get_iterable(axis)
 
     # reshape arrays as 2d matrices
-    # rows : samples; columns : variables
+    # rows: samples; columns: variables
     axis = tuple(range(pred.ndim)) if axis is None else axis
     axis = tuple(np.sort(axis))
     for ax in axis:
